/**
 * OW2 geolocalization
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Show.java 5360 2010-02-24 14:29:45Z benoitf $
 * --------------------------------------------------------------------------
 */
package org.ow2.util.geolocation.web.front;

import java.io.IOException;
import java.io.PrintWriter;
import java.util.List;
import javax.ejb.EJB;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.ow2.util.geolocation.business.GeoLocatorInterface;
import org.ow2.util.geolocation.business.entity.GeolocalisedProduct;

/**
 * A service servlet to show registered products.
 *
 * @author mancelin
 */
public class Show extends HttpServlet {

    /**
     * A null string.
     */
    private static final String NULL = "";
    /**
     * The geolocalization EJB.
     */
    @EJB
    private GeoLocatorInterface clientSess;

    /**
     * Processes requests for both HTTP <code>GET</code> and <code>POST</code> methods.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    protected void processRequest(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        response.setContentType("text/xml");
        PrintWriter out = response.getWriter();
        try {
            String product = request.getParameter("product");
            String version = request.getParameter("version");
            List productsList = null;
            if (product == null && version == null) {
                productsList = clientSess.getLocalisedProducts(NULL, NULL);
            } else if (product != null && version == null) {
                productsList = clientSess.getLocalisedProducts(product, NULL);
            } else if (product == null && version != null) {
                productsList = clientSess.getLocalisedProducts(NULL, version);
            } else {
                productsList = clientSess.getLocalisedProducts(product, version);
            }
            if (productsList.isEmpty()) {
                out.println("<products/>");
            } else {
                out.println("<?xml version=\"1.0\" encoding=\"ISO-8859-1\"?>");
                out.println("<products>");
                for (GeolocalisedProduct p : (List<GeolocalisedProduct>) productsList) {
                    out.println("<product name=\"" 
                            + p.getProductName()
                            + "\" version=\""
                            + p.getProductVersion()
                            + "\" city=\""
                            + p.getCity()
                            + "\" latitude=\""
                            + p.getLatitude()
                            + "\" longitude=\""
                            + p.getLongitude()
                            + "\"/>");
                }
                out.println("</products>");
            }
        } catch (Exception e) {
            out.println("<products/>");
        } finally {
            out.close();
        }
    }

    /** 
     * Handles the HTTP <code>GET</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doGet(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /** 
     * Handles the HTTP <code>POST</code> method.
     * @param request servlet request
     * @param response servlet response
     * @throws ServletException if a servlet-specific error occurs
     * @throws IOException if an I/O error occurs
     */
    @Override
    protected void doPost(final HttpServletRequest request, final HttpServletResponse response)
            throws ServletException, IOException {
        processRequest(request, response);
    }

    /** 
     * Returns a short description of the servlet.
     * @return a String containing servlet description
     */
    @Override
    public String getServletInfo() {
        return "Short description";
    }
}
